==> boostcrm-widget-1.0.2.tgz: package/es/commons/utils/correct-message.js <==
import _extends from 'babel-runtime/helpers/extends';
import _includes from 'lodash/includes';
import _isEmpty from 'lodash/isEmpty';
import _size from 'lodash/size';
import _get from 'lodash/get';

import { MESSAGE_TYPES } from '../constants/message-type';
import { SENDER_TYPES } from '../constants/sender-types';
var defaultIdForSubscriber = 'subscriber';
var defaultIdForBot = 'bot';
var listTypeMessageHide = [MESSAGE_TYPES.QUICK_REPLY, MESSAGE_TYPES.DELAY];

export var handleCorrectMessages = function handleCorrectMessages(messages) {
  if (_isEmpty(messages)) return [];
  var lastPosition = _size(messages) - 1;
  messages = (messages || []).map(function (message, index) {
    //correct senderId
    // let senderId = get(message, 'senderId') ? get(message, 'senderId') : get(message, 'senderType') === 1 ? defaultIdForSubscriber : defaultIdForBot;

    var senderType = _get(message, 'senderType');
    // if (!senderType) {
    //   console.log('senderType in: ', JSON.stringify(message));
    // }
    var senderId = senderType === SENDER_TYPES.ADMIN || senderType === SENDER_TYPES.BOT ? defaultIdForBot : senderType === SENDER_TYPES.SUBSCRIBER ? defaultIdForSubscriber : _get(message, 'senderId') ? _get(message, 'senderId') : defaultIdForSubscriber;
    // console.log(`senderType: ${senderType} - senderId: ${senderId}`);

    //QuickReply, Typing only show when they are at last message. They will be hidden if there are new coming messages or user select the button on quickReply
    if (_includes(listTypeMessageHide, _get(message, 'message.type')) && index !== lastPosition) {
      return _extends({}, message, {
        isHideMessage: true,
        senderId: senderId
      });
    }
    return _extends({}, message, {
      senderId: senderId
    });
  });
  return messages;
};

==> boostcrm-widget-1.0.8.tgz: package/es/commons/utils/correct-message.js <==
import _extends from "@babel/runtime/helpers/extends";
import _includes from "lodash/includes";
import _isEmpty from "lodash/isEmpty";
import _size from "lodash/size";
import _get from "lodash/get";
import { MESSAGE_TYPES } from '../constants/message-type';
import { SENDER_TYPES } from '../constants/sender-types';
var defaultIdForSubscriber = 'subscriber';
var defaultIdForBot = 'bot';
var listTypeMessageHide = [MESSAGE_TYPES.QUICK_REPLY, MESSAGE_TYPES.DELAY];
export var handleCorrectMessages = function handleCorrectMessages(messages) {
  if (_isEmpty(messages)) return [];
  var lastPosition = _size(messages) - 1;
  messages = (messages || []).map(function (message, index) {
    //correct senderId
    // let senderId = get(message, 'senderId') ? get(message, 'senderId') : get(message, 'senderType') === 1 ? defaultIdForSubscriber : defaultIdForBot;
    var senderType = _get(message, 'senderType'); // if (!senderType) {
    //   console.log('senderType in: ', JSON.stringify(message));
    // }


    var senderId = senderType === SENDER_TYPES.ADMIN || senderType === SENDER_TYPES.BOT ? defaultIdForBot : senderType === SENDER_TYPES.SUBSCRIBER ? defaultIdForSubscriber : _get(message, 'senderId') ? _get(message, 'senderId') : defaultIdForSubscriber; // console.log(`senderType: ${senderType} - senderId: ${senderId}`);
    //QuickReply, Typing only show when they are at last message. They will be hidden if there are new coming messages or user select the button on quickReply

    if (_includes(listTypeMessageHide, _get(message, 'message.type')) && index !== lastPosition) {
      return _extends({}, message, {
        isHideMessage: true,
        senderId: senderId
      });
    }

    return _extends({}, message, {
      senderId: senderId
    });
  });
  return messages;
};
